@@ -2,7 +2,7 @@ import json
 from typing import Dict
 from inspect import isclass
 
-__version__ = '0.6.4'
+__version__ = '0.6.5'
 
 renderers: Dict = {}
 
@@ -93,6 +93,16 @@ class Embed(BaseContainer):
         return f'<div class="embed-wrapper {provider_name.lower()}-wrapper"><figure>{html}</figure></div>'  # noqa: E501
 
 
+class Heading(BaseContainer):
+    type = "heading"
+
+    def inner_render(self, node) -> str:
+        attrs = node['attrs']
+        level = attrs.get('level') or 3
+        content = node.get('content', '')
+        return f"<h{level}>{content}</h{level}>"
+
+
 class Title(BaseContainer):
     type = "title"
     wrap_tag: str = "h1"
